
==========================
Leonardo leonardo-system
==========================

System Module to Leonardo CMS

Features
--------

* install/uninstall modules from pypi in one click
* check/update versions

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-system

Read More
=========

* https://github.com/django-leonardo/django-leonardo
